/* ProtoSnap LilyPad Simple Example Code
   by: Pete Lewis
   additional modification by: Jim Lindblom
   SparkFun Electronics
   date: September 10, 2012
   
   License: This code is released into the open domain. Please
   use, re-use, and modify this code in any, which way you
   require.
   
   This example code was written specifically for the ProtoSnap
   LilyPad Simple Development Board. At startup it'll turn on 
   each of the four LEDs (connected to pins 5, 6, 10, and 11)
   in succession. Then it'll play a short buzz. In the loop
   this program samples the resistive touch sensor on pin A3,
   if it senses anything it'll turn the touch pressure into
   a tone.
*/

int sensorPin = A3;  // sensor connected to analog pin a3
int sensorValue;  // The touch sensor's value is stored here
int speakerPin=9;  // Buzzer's + pin is connected here (- is to GND)

void setup() 
{
  // initialize the digital pin as an output.
  pinMode(13, OUTPUT); // Pin 13 is the LilyPad Simple's green LED
  pinMode(5, OUTPUT);  // left-most LED
  pinMode(6, OUTPUT);  // middle-left LED
  pinMode(10, OUTPUT);  // middle-right LED
  pinMode(11, OUTPUT);  // right-most LED
  pinMode(9, OUTPUT);  // buzzer + pin

  digitalWrite(sensorPin, HIGH);  // Use the pins internal pull-up

  digitalWrite(5, HIGH);   // set the LED on
  delay(1000);              // wait for a second
  digitalWrite(5, LOW);    // set the LED off 

  digitalWrite(6, HIGH);   // set the LED on
  delay(1000);              // wait for a second
  digitalWrite(6, LOW);    // set the LED off

  digitalWrite(10, HIGH);   // set the LED on
  delay(1000);              // wait for a second
  digitalWrite(10, LOW);    // set the LED off

  digitalWrite(11, HIGH);   // set the LED on
  delay(1000);              // wait for a second
  digitalWrite(11, LOW);    // set the LED off

  digitalWrite(13, HIGH);  // Turn the green LED on

  // play a 2000 kHz tone on the speaker for 1000ms (1s)
  tone(speakerPin,2000,1000);
}

void loop() 
{
  // First read the touch-sensor value, this will produce a number
  // between 0 and 1023.
  sensorValue = analogRead(sensorPin);
  // A touch-sensor value of more than 1000 indicates that the 
  // sensor is not being pressed. Anything less indicates varying
  // levels of touch pressure.
  if (sensorValue <1000)
  {
    // Play a tone on speakerPin for 10ms. The tone is dependent
    // on the value read from the touch sensor.
    tone (speakerPin, (1023-sensorValue)*10, 10);
  }
}
